@@ -17,7 +17,7 @@ medusa::time2text(const mdreal t) {
   /* Report days and hours. */
   if(day >= 1.0) {
     hrs -= ((unsigned long)day)*24;
-    sprintf(buf, "%ldd %ldh", (unsigned long)day,
+    snprintf(buf, sizeof(buf), "%ldd %ldh", (unsigned long)day,
 	    (unsigned long)(hrs + 0.5));
     return string(buf);
   }
@@ -25,7 +25,7 @@ medusa::time2text(const mdreal t) {
   /* Report hours and minutes. */
   if(hrs >= 1.0) {
     min -= ((unsigned long)hrs)*60;
-    sprintf(buf, "%ldh %ldm", (unsigned long)hrs,
+    snprintf(buf, sizeof(buf), "%ldh %ldm", (unsigned long)hrs,
 	    (unsigned long)(min + 0.5));
     return string(buf);
   }
@@ -33,13 +33,13 @@ medusa::time2text(const mdreal t) {
   /* Report minutes and seconds. */
   if(min >= 1.0) {
     sec -= ((unsigned long)min)*60;
-    sprintf(buf, "%ldm %lds", (unsigned long)min,
+    snprintf(buf, sizeof(buf), "%ldm %lds", (unsigned long)min,
 	    (unsigned long)(sec + 0.5));
     return string(buf);
   }
 
   /* Report seconds . */
-  if(sec < 1.0) sprintf(buf, "<1s");
-  else sprintf(buf, "%lds", (unsigned long)(sec + 0.5));
+  if(sec < 1.0) snprintf(buf, sizeof(buf), "<1s");
+  else snprintf(buf, sizeof(buf), "%lds", (unsigned long)(sec + 0.5));
   return string(buf);
 }
